/*@import url(https://fonts.googleapis.com/css?family=Source+Sans+Pro:200,300);*/

* {
	box-sizing: border-box;
	margin: 0;
	padding: 0;
	font-weight: 300;
}

body {
	font-family: 'Source Sans Pro', sans-serif;
	color: white;
	font-weight: 300;
    background: #53c0e3;
    background: -webkit-linear-gradient(top left, #e1eff6 0%, #164757 100%);
    background: -moz-linear-gradient(top left, #e1eff6 0%, #164757 100%);
    background: -o-linear-gradient(top left, #e1eff6 0%, #164757 100%);
    background: linear-gradient(to bottom right, #e1eff6 0%, #164757 100%);
}

body ::-webkit-input-placeholder {
  /* WebKit browsers */
	font-family: 'Source Sans Pro', sans-serif;
	color: white;
	font-weight: 300;
}

body :-moz-placeholder {
  /* Mozilla Firefox 4 to 18 */
	font-family: 'Source Sans Pro', sans-serif;
	color: white;
	opacity: 1;
	font-weight: 300;
}

body ::-moz-placeholder {
  /* Mozilla Firefox 19+ */
	font-family: 'Source Sans Pro', sans-serif;
	color: white;
	opacity: 1;
	font-weight: 300;
}

body :-ms-input-placeholder {
  /* Internet Explorer 10+ */
	font-family: 'Source Sans Pro', sans-serif;
	color: white;
	font-weight: 300;
}

.error {
	color: #fff;
    font-weight: 700;
    border-bottom: solid 3px #f00c0c99;
    width: 240px;
	padding: 0 0 5px;
	margin: 0 auto 20px;
	font-size: 18px;
}

.wrapper {
	position: absolute;
	top: 30%;
	left: 0;
	width: 100%;
	height: 400px;
	margin-top: -200px;
	/*! overflow: hidden; */
}

.wrapper.form-success .container h1 {
	transform: translateY(85px);
}

.container {
	max-width: 600px;
	margin: 0 auto;
	padding: 80px 0;
	height: 500px;
	text-align: center;
}

.container h1 {
	font-size: 40px;
	transition-duration: 1s;
	transition-timing-function: ease-in-put;
	font-weight: 200;
}

form {
	padding: 60px 0;
	position: relative;
	z-index: 2;
}

form input {
	appearance: none;
	outline: 0;
	border: 1px solid rgba(255, 255, 255, 0.4);
	background-color: rgba(255, 255, 255, 0);
	width: 300px;
	border-radius: 2px;
	padding: 10px 15px;
	margin: 0 auto 10px auto;
	display: block;
	text-align: center;
	font-size: 18px;
	color: white;
	transition-duration: 0.25s;
	font-weight: 300;
}

form input:hover {
	background-color: rgba(255, 255, 255, 0.4);
}

form input:focus {
	background-color: white;
	color: #666666;
}

form button {
    margin-top: 40px;
    outline: 0;
    background-color: white;
    border: 0;
    color: #595959;
    border-radius: 2px;
    width: 150px;
    cursor: pointer;
    font-size: 16px;
    transition-duration: 0.25s;
    padding: 10px;
}

form button:hover {
	background-color: #f5f7f9;
}
